# Stock-Market-Analytics
System for live/historical stock market analysis and visualization. 
- Access and analyze company information/financials
- Integrated with MongoDB Atlas cloud database
- Visualize stock prices in real time using Jupyter Notebook
- Extract Data From:
    * Yahoo_Finance
    * Wikipedia 
    * Twitter

Features in Development:
- Power BI & Tableau dashboards
- Twitter sentiment analysis
- Machine learning models for predictive analytics
- Flask REST API and web app
